// Copyright (C) 2022 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

export 'indicator.dart';
export 'spinner.dart';
export 'spinner_type.dart';

// From https://raw.githubusercontent.com/sindresorhus/cli-spinners/master/spinners.json
const Map<String, Map<String, Object>> spinners = <String, Map<String, Object>>{
  'dots': <String, Object>{
    'interval': 80,
    'frames': <String>['⠋', '⠙', '⠹', '⠸', '⠼', '⠴', '⠦', '⠧', '⠇', '⠏']
  },
  'dots2': <String, Object>{
    'interval': 80,
    'frames': <String>['⣾', '⣽', '⣻', '⢿', '⡿', '⣟', '⣯', '⣷']
  },
  'dots3': <String, Object>{
    'interval': 80,
    'frames': <String>['⠋', '⠙', '⠚', '⠞', '⠖', '⠦', '⠴', '⠲', '⠳', '⠓']
  },
  'dots4': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⠄',
      '⠆',
      '⠇',
      '⠋',
      '⠙',
      '⠸',
      '⠰',
      '⠠',
      '⠰',
      '⠸',
      '⠙',
      '⠋',
      '⠇',
      '⠆'
    ]
  },
  'dots5': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⠋',
      '⠙',
      '⠚',
      '⠒',
      '⠂',
      '⠂',
      '⠒',
      '⠲',
      '⠴',
      '⠦',
      '⠖',
      '⠒',
      '⠐',
      '⠐',
      '⠒',
      '⠓',
      '⠋'
    ]
  },
  'dots6': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⠁',
      '⠉',
      '⠙',
      '⠚',
      '⠒',
      '⠂',
      '⠂',
      '⠒',
      '⠲',
      '⠴',
      '⠤',
      '⠄',
      '⠄',
      '⠤',
      '⠴',
      '⠲',
      '⠒',
      '⠂',
      '⠂',
      '⠒',
      '⠚',
      '⠙',
      '⠉',
      '⠁'
    ]
  },
  'dots7': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⠈',
      '⠉',
      '⠋',
      '⠓',
      '⠒',
      '⠐',
      '⠐',
      '⠒',
      '⠖',
      '⠦',
      '⠤',
      '⠠',
      '⠠',
      '⠤',
      '⠦',
      '⠖',
      '⠒',
      '⠐',
      '⠐',
      '⠒',
      '⠓',
      '⠋',
      '⠉',
      '⠈'
    ]
  },
  'dots8': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⠁',
      '⠁',
      '⠉',
      '⠙',
      '⠚',
      '⠒',
      '⠂',
      '⠂',
      '⠒',
      '⠲',
      '⠴',
      '⠤',
      '⠄',
      '⠄',
      '⠤',
      '⠠',
      '⠠',
      '⠤',
      '⠦',
      '⠖',
      '⠒',
      '⠐',
      '⠐',
      '⠒',
      '⠓',
      '⠋',
      '⠉',
      '⠈',
      '⠈'
    ]
  },
  'dots9': <String, Object>{
    'interval': 80,
    'frames': <String>['⢹', '⢺', '⢼', '⣸', '⣇', '⡧', '⡗', '⡏']
  },
  'dots10': <String, Object>{
    'interval': 80,
    'frames': <String>['⢄', '⢂', '⢁', '⡁', '⡈', '⡐', '⡠']
  },
  'dots11': <String, Object>{
    'interval': 100,
    'frames': <String>['⠁', '⠂', '⠄', '⡀', '⢀', '⠠', '⠐', '⠈']
  },
  'dots12': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⢀⠀',
      '⡀⠀',
      '⠄⠀',
      '⢂⠀',
      '⡂⠀',
      '⠅⠀',
      '⢃⠀',
      '⡃⠀',
      '⠍⠀',
      '⢋⠀',
      '⡋⠀',
      '⠍⠁',
      '⢋⠁',
      '⡋⠁',
      '⠍⠉',
      '⠋⠉',
      '⠋⠉',
      '⠉⠙',
      '⠉⠙',
      '⠉⠩',
      '⠈⢙',
      '⠈⡙',
      '⢈⠩',
      '⡀⢙',
      '⠄⡙',
      '⢂⠩',
      '⡂⢘',
      '⠅⡘',
      '⢃⠨',
      '⡃⢐',
      '⠍⡐',
      '⢋⠠',
      '⡋⢀',
      '⠍⡁',
      '⢋⠁',
      '⡋⠁',
      '⠍⠉',
      '⠋⠉',
      '⠋⠉',
      '⠉⠙',
      '⠉⠙',
      '⠉⠩',
      '⠈⢙',
      '⠈⡙',
      '⠈⠩',
      '⠀⢙',
      '⠀⡙',
      '⠀⠩',
      '⠀⢘',
      '⠀⡘',
      '⠀⠨',
      '⠀⢐',
      '⠀⡐',
      '⠀⠠',
      '⠀⢀',
      '⠀⡀'
    ]
  },
  'dots8Bit': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '⠀',
      '⠁',
      '⠂',
      '⠃',
      '⠄',
      '⠅',
      '⠆',
      '⠇',
      '⡀',
      '⡁',
      '⡂',
      '⡃',
      '⡄',
      '⡅',
      '⡆',
      '⡇',
      '⠈',
      '⠉',
      '⠊',
      '⠋',
      '⠌',
      '⠍',
      '⠎',
      '⠏',
      '⡈',
      '⡉',
      '⡊',
      '⡋',
      '⡌',
      '⡍',
      '⡎',
      '⡏',
      '⠐',
      '⠑',
      '⠒',
      '⠓',
      '⠔',
      '⠕',
      '⠖',
      '⠗',
      '⡐',
      '⡑',
      '⡒',
      '⡓',
      '⡔',
      '⡕',
      '⡖',
      '⡗',
      '⠘',
      '⠙',
      '⠚',
      '⠛',
      '⠜',
      '⠝',
      '⠞',
      '⠟',
      '⡘',
      '⡙',
      '⡚',
      '⡛',
      '⡜',
      '⡝',
      '⡞',
      '⡟',
      '⠠',
      '⠡',
      '⠢',
      '⠣',
      '⠤',
      '⠥',
      '⠦',
      '⠧',
      '⡠',
      '⡡',
      '⡢',
      '⡣',
      '⡤',
      '⡥',
      '⡦',
      '⡧',
      '⠨',
      '⠩',
      '⠪',
      '⠫',
      '⠬',
      '⠭',
      '⠮',
      '⠯',
      '⡨',
      '⡩',
      '⡪',
      '⡫',
      '⡬',
      '⡭',
      '⡮',
      '⡯',
      '⠰',
      '⠱',
      '⠲',
      '⠳',
      '⠴',
      '⠵',
      '⠶',
      '⠷',
      '⡰',
      '⡱',
      '⡲',
      '⡳',
      '⡴',
      '⡵',
      '⡶',
      '⡷',
      '⠸',
      '⠹',
      '⠺',
      '⠻',
      '⠼',
      '⠽',
      '⠾',
      '⠿',
      '⡸',
      '⡹',
      '⡺',
      '⡻',
      '⡼',
      '⡽',
      '⡾',
      '⡿',
      '⢀',
      '⢁',
      '⢂',
      '⢃',
      '⢄',
      '⢅',
      '⢆',
      '⢇',
      '⣀',
      '⣁',
      '⣂',
      '⣃',
      '⣄',
      '⣅',
      '⣆',
      '⣇',
      '⢈',
      '⢉',
      '⢊',
      '⢋',
      '⢌',
      '⢍',
      '⢎',
      '⢏',
      '⣈',
      '⣉',
      '⣊',
      '⣋',
      '⣌',
      '⣍',
      '⣎',
      '⣏',
      '⢐',
      '⢑',
      '⢒',
      '⢓',
      '⢔',
      '⢕',
      '⢖',
      '⢗',
      '⣐',
      '⣑',
      '⣒',
      '⣓',
      '⣔',
      '⣕',
      '⣖',
      '⣗',
      '⢘',
      '⢙',
      '⢚',
      '⢛',
      '⢜',
      '⢝',
      '⢞',
      '⢟',
      '⣘',
      '⣙',
      '⣚',
      '⣛',
      '⣜',
      '⣝',
      '⣞',
      '⣟',
      '⢠',
      '⢡',
      '⢢',
      '⢣',
      '⢤',
      '⢥',
      '⢦',
      '⢧',
      '⣠',
      '⣡',
      '⣢',
      '⣣',
      '⣤',
      '⣥',
      '⣦',
      '⣧',
      '⢨',
      '⢩',
      '⢪',
      '⢫',
      '⢬',
      '⢭',
      '⢮',
      '⢯',
      '⣨',
      '⣩',
      '⣪',
      '⣫',
      '⣬',
      '⣭',
      '⣮',
      '⣯',
      '⢰',
      '⢱',
      '⢲',
      '⢳',
      '⢴',
      '⢵',
      '⢶',
      '⢷',
      '⣰',
      '⣱',
      '⣲',
      '⣳',
      '⣴',
      '⣵',
      '⣶',
      '⣷',
      '⢸',
      '⢹',
      '⢺',
      '⢻',
      '⢼',
      '⢽',
      '⢾',
      '⢿',
      '⣸',
      '⣹',
      '⣺',
      '⣻',
      '⣼',
      '⣽',
      '⣾',
      '⣿'
    ]
  },
  'line': <String, Object>{
    'interval': 130,
    'frames': <String>['-', r'\', '|', '/']
  },
  'line2': <String, Object>{
    'interval': 100,
    'frames': <String>['⠂', '-', '–', '—', '–', '-']
  },
  'pipe': <String, Object>{
    'interval': 100,
    'frames': <String>['┤', '┘', '┴', '└', '├', '┌', '┬', '┐']
  },
  'simpleDots': <String, Object>{
    'interval': 400,
    'frames': <String>['.  ', '.. ', '...', '   ']
  },
  'simpleDotsScrolling': <String, Object>{
    'interval': 200,
    'frames': <String>['.  ', '.. ', '...', ' ..', '  .', '   ']
  },
  'star': <String, Object>{
    'interval': 70,
    'frames': <String>['✶', '✸', '✹', '✺', '✹', '✷']
  },
  'star2': <String, Object>{
    'interval': 80,
    'frames': <String>['+', 'x', '*']
  },
  'flip': <String, Object>{
    'interval': 70,
    'frames': <String>[
      '_',
      '_',
      '_',
      '-',
      '`',
      '`',
      "'",
      '´',
      '-',
      '_',
      '_',
      '_',
    ]
  },
  'hamburger': <String, Object>{
    'interval': 100,
    'frames': <String>['☱', '☲', '☴']
  },
  'growVertical': <String, Object>{
    'interval': 120,
    'frames': <String>['▁', '▃', '▄', '▅', '▆', '▇', '▆', '▅', '▄', '▃']
  },
  'growHorizontal': <String, Object>{
    'interval': 120,
    'frames': <String>[
      '▏',
      '▎',
      '▍',
      '▌',
      '▋',
      '▊',
      '▉',
      '▊',
      '▋',
      '▌',
      '▍',
      '▎'
    ]
  },
  'balloon': <String, Object>{
    'interval': 140,
    'frames': <String>[' ', '.', 'o', 'O', '@', '*', ' ']
  },
  'balloon2': <String, Object>{
    'interval': 120,
    'frames': <String>['.', 'o', 'O', '°', 'O', 'o', '.']
  },
  'noise': <String, Object>{
    'interval': 100,
    'frames': <String>['▓', '▒', '░']
  },
  'bounce': <String, Object>{
    'interval': 120,
    'frames': <String>['⠁', '⠂', '⠄', '⠂']
  },
  'boxBounce': <String, Object>{
    'interval': 120,
    'frames': <String>['▖', '▘', '▝', '▗']
  },
  'boxBounce2': <String, Object>{
    'interval': 100,
    'frames': <String>['▌', '▀', '▐', '▄']
  },
  'triangle': <String, Object>{
    'interval': 50,
    'frames': <String>['◢', '◣', '◤', '◥']
  },
  'arc': <String, Object>{
    'interval': 100,
    'frames': <String>['◜', '◠', '◝', '◞', '◡', '◟']
  },
  'circle': <String, Object>{
    'interval': 120,
    'frames': <String>['◡', '⊙', '◠']
  },
  'squareCorners': <String, Object>{
    'interval': 180,
    'frames': <String>['◰', '◳', '◲', '◱']
  },
  'circleQuarters': <String, Object>{
    'interval': 120,
    'frames': <String>['◴', '◷', '◶', '◵']
  },
  'circleHalves': <String, Object>{
    'interval': 50,
    'frames': <String>['◐', '◓', '◑', '◒']
  },
  'squish': <String, Object>{
    'interval': 100,
    'frames': <String>['╫', '╪']
  },
  'toggle': <String, Object>{
    'interval': 250,
    'frames': <String>['⊶', '⊷']
  },
  'toggle2': <String, Object>{
    'interval': 80,
    'frames': <String>['▫', '▪']
  },
  'toggle3': <String, Object>{
    'interval': 120,
    'frames': <String>['□', '■']
  },
  'toggle4': <String, Object>{
    'interval': 100,
    'frames': <String>['■', '□', '▪', '▫']
  },
  'toggle5': <String, Object>{
    'interval': 100,
    'frames': <String>['▮', '▯']
  },
  'toggle6': <String, Object>{
    'interval': 300,
    'frames': <String>['ဝ', '၀']
  },
  'toggle7': <String, Object>{
    'interval': 80,
    'frames': <String>['⦾', '⦿']
  },
  'toggle8': <String, Object>{
    'interval': 100,
    'frames': <String>['◍', '◌']
  },
  'toggle9': <String, Object>{
    'interval': 100,
    'frames': <String>['◉', '◎']
  },
  'toggle10': <String, Object>{
    'interval': 100,
    'frames': <String>['㊂', '㊀', '㊁']
  },
  'toggle11': <String, Object>{
    'interval': 50,
    'frames': <String>['⧇', '⧆']
  },
  'toggle12': <String, Object>{
    'interval': 120,
    'frames': <String>['☗', '☖']
  },
  'toggle13': <String, Object>{
    'interval': 80,
    'frames': <String>['=', '*', '-']
  },
  'arrow': <String, Object>{
    'interval': 100,
    'frames': <String>['←', '↖', '↑', '↗', '→', '↘', '↓', '↙']
  },
  'arrow2': <String, Object>{
    'interval': 80,
    'frames': <String>['⬆️ ', '↗️ ', '➡️ ', '↘️ ', '⬇️ ', '↙️ ', '⬅️ ', '↖️ ']
  },
  'arrow3': <String, Object>{
    'interval': 120,
    'frames': <String>['▹▹▹▹▹', '▸▹▹▹▹', '▹▸▹▹▹', '▹▹▸▹▹', '▹▹▹▸▹', '▹▹▹▹▸']
  },
  'bouncingBar': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '[    ]',
      '[=   ]',
      '[==  ]',
      '[=== ]',
      '[ ===]',
      '[  ==]',
      '[   =]',
      '[    ]',
      '[   =]',
      '[  ==]',
      '[ ===]',
      '[====]',
      '[=== ]',
      '[==  ]',
      '[=   ]'
    ]
  },
  'bouncingBall': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '( ●    )',
      '(  ●   )',
      '(   ●  )',
      '(    ● )',
      '(     ●)',
      '(    ● )',
      '(   ●  )',
      '(  ●   )',
      '( ●    )',
      '(●     )'
    ]
  },
  'smiley': <String, Object>{
    'interval': 200,
    'frames': <String>['😄 ', '😝 ']
  },
  'monkey': <String, Object>{
    'interval': 300,
    'frames': <String>['🙈 ', '🙈 ', '🙉 ', '🙊 ']
  },
  'hearts': <String, Object>{
    'interval': 100,
    'frames': <String>['💛 ', '💙 ', '💜 ', '💚 ', '❤️ ']
  },
  'clock': <String, Object>{
    'interval': 100,
    'frames': <String>[
      '🕛 ',
      '🕐 ',
      '🕑 ',
      '🕒 ',
      '🕓 ',
      '🕔 ',
      '🕕 ',
      '🕖 ',
      '🕗 ',
      '🕘 ',
      '🕙 ',
      '🕚 '
    ]
  },
  'earth': <String, Object>{
    'interval': 180,
    'frames': <String>['🌍 ', '🌎 ', '🌏 ']
  },
  'material': <String, Object>{
    'interval': 17,
    'frames': <String>[
      '█▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '██▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '███▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '████▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '██████▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '██████▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '███████▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '████████▁▁▁▁▁▁▁▁▁▁▁▁',
      '█████████▁▁▁▁▁▁▁▁▁▁▁',
      '█████████▁▁▁▁▁▁▁▁▁▁▁',
      '██████████▁▁▁▁▁▁▁▁▁▁',
      '███████████▁▁▁▁▁▁▁▁▁',
      '█████████████▁▁▁▁▁▁▁',
      '██████████████▁▁▁▁▁▁',
      '██████████████▁▁▁▁▁▁',
      '▁██████████████▁▁▁▁▁',
      '▁██████████████▁▁▁▁▁',
      '▁██████████████▁▁▁▁▁',
      '▁▁██████████████▁▁▁▁',
      '▁▁▁██████████████▁▁▁',
      '▁▁▁▁█████████████▁▁▁',
      '▁▁▁▁██████████████▁▁',
      '▁▁▁▁██████████████▁▁',
      '▁▁▁▁▁██████████████▁',
      '▁▁▁▁▁██████████████▁',
      '▁▁▁▁▁██████████████▁',
      '▁▁▁▁▁▁██████████████',
      '▁▁▁▁▁▁██████████████',
      '▁▁▁▁▁▁▁█████████████',
      '▁▁▁▁▁▁▁█████████████',
      '▁▁▁▁▁▁▁▁████████████',
      '▁▁▁▁▁▁▁▁████████████',
      '▁▁▁▁▁▁▁▁▁███████████',
      '▁▁▁▁▁▁▁▁▁███████████',
      '▁▁▁▁▁▁▁▁▁▁██████████',
      '▁▁▁▁▁▁▁▁▁▁██████████',
      '▁▁▁▁▁▁▁▁▁▁▁▁████████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁███████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁██████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁█████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁█████',
      '█▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁████',
      '██▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁███',
      '██▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁███',
      '███▁▁▁▁▁▁▁▁▁▁▁▁▁▁███',
      '████▁▁▁▁▁▁▁▁▁▁▁▁▁▁██',
      '█████▁▁▁▁▁▁▁▁▁▁▁▁▁▁█',
      '█████▁▁▁▁▁▁▁▁▁▁▁▁▁▁█',
      '██████▁▁▁▁▁▁▁▁▁▁▁▁▁█',
      '████████▁▁▁▁▁▁▁▁▁▁▁▁',
      '█████████▁▁▁▁▁▁▁▁▁▁▁',
      '█████████▁▁▁▁▁▁▁▁▁▁▁',
      '█████████▁▁▁▁▁▁▁▁▁▁▁',
      '█████████▁▁▁▁▁▁▁▁▁▁▁',
      '███████████▁▁▁▁▁▁▁▁▁',
      '████████████▁▁▁▁▁▁▁▁',
      '████████████▁▁▁▁▁▁▁▁',
      '██████████████▁▁▁▁▁▁',
      '██████████████▁▁▁▁▁▁',
      '▁██████████████▁▁▁▁▁',
      '▁██████████████▁▁▁▁▁',
      '▁▁▁█████████████▁▁▁▁',
      '▁▁▁▁▁████████████▁▁▁',
      '▁▁▁▁▁████████████▁▁▁',
      '▁▁▁▁▁▁███████████▁▁▁',
      '▁▁▁▁▁▁▁▁█████████▁▁▁',
      '▁▁▁▁▁▁▁▁█████████▁▁▁',
      '▁▁▁▁▁▁▁▁▁█████████▁▁',
      '▁▁▁▁▁▁▁▁▁█████████▁▁',
      '▁▁▁▁▁▁▁▁▁▁█████████▁',
      '▁▁▁▁▁▁▁▁▁▁▁████████▁',
      '▁▁▁▁▁▁▁▁▁▁▁████████▁',
      '▁▁▁▁▁▁▁▁▁▁▁▁███████▁',
      '▁▁▁▁▁▁▁▁▁▁▁▁███████▁',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁███████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁███████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁█████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁████',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁███',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁███',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁██',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁██',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁██',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁█',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁█',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁█',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁',
      '▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁'
    ]
  },
  'moon': <String, Object>{
    'interval': 80,
    'frames': <String>['🌑 ', '🌒 ', '🌓 ', '🌔 ', '🌕 ', '🌖 ', '🌗 ', '🌘 ']
  },
  'runner': <String, Object>{
    'interval': 140,
    'frames': <String>['🚶 ', '🏃 ']
  },
  'pong': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '▐⠂       ▌',
      '▐⠈       ▌',
      '▐ ⠂      ▌',
      '▐ ⠠      ▌',
      '▐  ⡀     ▌',
      '▐  ⠠     ▌',
      '▐   ⠂    ▌',
      '▐   ⠈    ▌',
      '▐    ⠂   ▌',
      '▐    ⠠   ▌',
      '▐     ⡀  ▌',
      '▐     ⠠  ▌',
      '▐      ⠂ ▌',
      '▐      ⠈ ▌',
      '▐       ⠂▌',
      '▐       ⠠▌',
      '▐       ⡀▌',
      '▐      ⠠ ▌',
      '▐      ⠂ ▌',
      '▐     ⠈  ▌',
      '▐     ⠂  ▌',
      '▐    ⠠   ▌',
      '▐    ⡀   ▌',
      '▐   ⠠    ▌',
      '▐   ⠂    ▌',
      '▐  ⠈     ▌',
      '▐  ⠂     ▌',
      '▐ ⠠      ▌',
      '▐ ⡀      ▌',
      '▐⠠       ▌'
    ]
  },
  'shark': <String, Object>{
    'interval': 120,
    'frames': <String>[
      r'▐|\____________▌',
      r'▐_|\___________▌',
      r'▐__|\__________▌',
      r'▐___|\_________▌',
      r'▐____|\________▌',
      r'▐_____|\_______▌',
      r'▐______|\______▌',
      r'▐_______|\_____▌',
      r'▐________|\____▌',
      r'▐_________|\___▌',
      r'▐__________|\__▌',
      r'▐___________|\_▌',
      r'▐____________|\▌',
      '▐____________/|▌',
      '▐___________/|_▌',
      '▐__________/|__▌',
      '▐_________/|___▌',
      '▐________/|____▌',
      '▐_______/|_____▌',
      '▐______/|______▌',
      '▐_____/|_______▌',
      '▐____/|________▌',
      '▐___/|_________▌',
      '▐__/|__________▌',
      '▐_/|___________▌',
      '▐/|____________▌'
    ]
  },
  'dqpb': <String, Object>{
    'interval': 100,
    'frames': <String>['d', 'q', 'p', 'b']
  },
  'weather': <String, Object>{
    'interval': 100,
    'frames': <String>[
      '☀️ ',
      '☀️ ',
      '☀️ ',
      '🌤 ',
      '⛅️ ',
      '🌥 ',
      '☁️ ',
      '🌧 ',
      '🌨 ',
      '🌧 ',
      '🌨 ',
      '🌧 ',
      '🌨 ',
      '⛈ ',
      '🌨 ',
      '🌧 ',
      '🌨 ',
      '☁️ ',
      '🌥 ',
      '⛅️ ',
      '🌤 ',
      '☀️ ',
      '☀️ '
    ]
  },
  'christmas': <String, Object>{
    'interval': 400,
    'frames': <String>['🌲', '🎄']
  },
  'grenade': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '،  ',
      '′  ',
      ' ´ ',
      ' ‾ ',
      '  ⸌',
      '  ⸊',
      '  |',
      '  ⁎',
      '  ⁕',
      ' ෴ ',
      '  ⁓',
      '   ',
      '   ',
      '   '
    ]
  },
  'point': <String, Object>{
    'interval': 125,
    'frames': <String>['∙∙∙', '●∙∙', '∙●∙', '∙∙●', '∙∙∙']
  },
  'layer': <String, Object>{
    'interval': 150,
    'frames': <String>['-', '=', '≡']
  },
  'betaWave': <String, Object>{
    'interval': 80,
    'frames': <String>[
      'ρββββββ',
      'βρβββββ',
      'ββρββββ',
      'βββρβββ',
      'ββββρββ',
      'βββββρβ',
      'ββββββρ'
    ]
  },
  'fingerDance': <String, Object>{
    'interval': 160,
    'frames': <String>['🤘 ', '🤟 ', '🖖 ', '✋ ', '🤚 ', '👆 ']
  },
  'fistBump': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '🤜\u3000\u3000\u3000\u3000🤛 ',
      '🤜\u3000\u3000\u3000\u3000🤛 ',
      '🤜\u3000\u3000\u3000\u3000🤛 ',
      '\u3000🤜\u3000\u3000🤛\u3000 ',
      '\u3000\u3000🤜🤛\u3000\u3000 ',
      '\u3000🤜✨🤛\u3000\u3000 ',
      '🤜\u3000✨\u3000🤛\u3000 '
    ]
  },
  'soccerHeader': <String, Object>{
    'interval': 80,
    'frames': <String>[
      ' 🧑⚽️       🧑 ',
      '🧑  ⚽️      🧑 ',
      '🧑   ⚽️     🧑 ',
      '🧑    ⚽️    🧑 ',
      '🧑     ⚽️   🧑 ',
      '🧑      ⚽️  🧑 ',
      '🧑       ⚽️🧑  ',
      '🧑      ⚽️  🧑 ',
      '🧑     ⚽️   🧑 ',
      '🧑    ⚽️    🧑 ',
      '🧑   ⚽️     🧑 ',
      '🧑  ⚽️      🧑 '
    ]
  },
  'mindblown': <String, Object>{
    'interval': 160,
    'frames': <String>[
      '😐 ',
      '😐 ',
      '😮 ',
      '😮 ',
      '😦 ',
      '😦 ',
      '😧 ',
      '😧 ',
      '🤯 ',
      '💥 ',
      '✨ ',
      '\u3000 ',
      '\u3000 ',
      '\u3000 '
    ]
  },
  'speaker': <String, Object>{
    'interval': 160,
    'frames': <String>['🔈 ', '🔉 ', '🔊 ', '🔉 ']
  },
  'orangePulse': <String, Object>{
    'interval': 100,
    'frames': <String>['🔸 ', '🔶 ', '🟠 ', '🟠 ', '🔶 ']
  },
  'bluePulse': <String, Object>{
    'interval': 100,
    'frames': <String>['🔹 ', '🔷 ', '🔵 ', '🔵 ', '🔷 ']
  },
  'orangeBluePulse': <String, Object>{
    'interval': 100,
    'frames': <String>[
      '🔸 ',
      '🔶 ',
      '🟠 ',
      '🟠 ',
      '🔶 ',
      '🔹 ',
      '🔷 ',
      '🔵 ',
      '🔵 ',
      '🔷 '
    ]
  },
  'timeTravel': <String, Object>{
    'interval': 100,
    'frames': <String>[
      '🕛 ',
      '🕚 ',
      '🕙 ',
      '🕘 ',
      '🕗 ',
      '🕖 ',
      '🕕 ',
      '🕔 ',
      '🕓 ',
      '🕒 ',
      '🕑 ',
      '🕐 '
    ]
  },
  'aesthetic': <String, Object>{
    'interval': 80,
    'frames': <String>[
      '▰▱▱▱▱▱▱',
      '▰▰▱▱▱▱▱',
      '▰▰▰▱▱▱▱',
      '▰▰▰▰▱▱▱',
      '▰▰▰▰▰▱▱',
      '▰▰▰▰▰▰▱',
      '▰▰▰▰▰▰▰',
      '▰▱▱▱▱▱▱'
    ]
  }
};
